summaryrefslogtreecommitdiffstats
path: root/filters/kspread
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit04766b207afba7961d4d802313e426f5a2fbef63 (patch)
treec888ea1027c793e2d0386a7e5a1a0cd077b03cb3 /filters/kspread
parentb6edfe41c9395f2e20784cbf0e630af6426950a3 (diff)
downloadkoffice-04766b207afba7961d4d802313e426f5a2fbef63.tar.gz
koffice-04766b207afba7961d4d802313e426f5a2fbef63.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'filters/kspread')
-rw-r--r--filters/kspread/applixspread/applixspreadimport.cc2
-rw-r--r--filters/kspread/applixspread/applixspreadimport.h2
-rw-r--r--filters/kspread/csv/csvdialog.cpp6
-rw-r--r--filters/kspread/csv/csvdialog.h2
-rw-r--r--filters/kspread/csv/csvexport.h2
-rw-r--r--filters/kspread/csv/csvexportdialog.cpp6
-rw-r--r--filters/kspread/csv/csvexportdialog.h2
-rw-r--r--filters/kspread/csv/csvimport.h2
-rw-r--r--filters/kspread/dbase/dbaseimport.h2
-rw-r--r--filters/kspread/excel/excelexport.h2
-rw-r--r--filters/kspread/excel/import/excelimport.h2
-rw-r--r--filters/kspread/excel/sidewinder/excel.h4
-rw-r--r--filters/kspread/excel/sidewinder/pole.cpp20
-rw-r--r--filters/kspread/gnumeric/gnumericexport.h2
-rw-r--r--filters/kspread/gnumeric/gnumericimport.h2
-rw-r--r--filters/kspread/html/exportdialog.cc4
-rw-r--r--filters/kspread/html/exportdialog.h2
-rw-r--r--filters/kspread/html/htmlexport.h2
-rw-r--r--filters/kspread/kexi/kspread_kexiimport.cc2
-rw-r--r--filters/kspread/kexi/kspread_kexiimport.h2
-rw-r--r--filters/kspread/kexi/kspread_kexiimportdialog.cc6
-rw-r--r--filters/kspread/kexi/kspread_kexiimportdialog.h2
-rw-r--r--filters/kspread/latex/export/format.h2
-rw-r--r--filters/kspread/latex/export/kspreadlatexexportdiaImpl.cc6
-rw-r--r--filters/kspread/latex/export/kspreadlatexexportdiaImpl.h2
-rw-r--r--filters/kspread/latex/export/latexexport.h2
-rw-r--r--filters/kspread/latex/export/latexexportIface.cc2
-rw-r--r--filters/kspread/opencalc/opencalcexport.cc48
-rw-r--r--filters/kspread/opencalc/opencalcexport.h6
-rw-r--r--filters/kspread/opencalc/opencalcimport.cc10
-rw-r--r--filters/kspread/opencalc/opencalcimport.h2
-rw-r--r--filters/kspread/opencalc/opencalcstyleexport.cc2
-rw-r--r--filters/kspread/qpro/qproimport.h2
33 files changed, 81 insertions, 81 deletions
diff --git a/filters/kspread/applixspread/applixspreadimport.cc b/filters/kspread/applixspread/applixspreadimport.cc
index ab3201c8..a75cccac 100644
--- a/filters/kspread/applixspread/applixspreadimport.cc
+++ b/filters/kspread/applixspread/applixspreadimport.cc
@@ -37,7 +37,7 @@ typedef KGenericFactory<APPLIXSPREADImport, KoFilter> APPLIXSPREADImportFactory;
K_EXPORT_COMPONENT_FACTORY( libapplixspreadimport, APPLIXSPREADImportFactory( "kofficefilters" ) )
-APPLIXSPREADImport::APPLIXSPREADImport ( TQObject */*tqparent*/, const char* /*name*/, const TQStringList& )
+APPLIXSPREADImport::APPLIXSPREADImport ( TQObject */*parent*/, const char* /*name*/, const TQStringList& )
: KoFilter()
{
}
diff --git a/filters/kspread/applixspread/applixspreadimport.h b/filters/kspread/applixspread/applixspreadimport.h
index 048a22e7..78deb2ca 100644
--- a/filters/kspread/applixspread/applixspreadimport.h
+++ b/filters/kspread/applixspread/applixspreadimport.h
@@ -54,7 +54,7 @@ class APPLIXSPREADImport : public KoFilter {
TQ_OBJECT
public:
- APPLIXSPREADImport ( TQObject *tqparent, const char* name, const TQStringList& );
+ APPLIXSPREADImport ( TQObject *parent, const char* name, const TQStringList& );
virtual ~APPLIXSPREADImport() {}
virtual KoFilter::ConversiontqStatus convert( const TQCString& from, const TQCString& to );
diff --git a/filters/kspread/csv/csvdialog.h b/filters/kspread/csv/csvdialog.h
index 685bbf37..eefb9407 100644
--- a/filters/kspread/csv/csvdialog.h
+++ b/filters/kspread/csv/csvdialog.h
@@ -42,7 +42,7 @@ public:
POINTNUMBER ///< Number, which decimal symbol is a point/dot
};
- CSVDialog(TQWidget* tqparent, TQByteArray& fileArray, const TQString seperator);
+ CSVDialog(TQWidget* parent, TQByteArray& fileArray, const TQString seperator);
~CSVDialog();
int getRows();
diff --git a/filters/kspread/csv/csvexport.h b/filters/kspread/csv/csvexport.h
index 53fd9efe..decdb81c 100644
--- a/filters/kspread/csv/csvexport.h
+++ b/filters/kspread/csv/csvexport.h
@@ -35,7 +35,7 @@ class CSVExport : public KoFilter
TQ_OBJECT
public:
- CSVExport(KoFilter * tqparent, const char * name, const TQStringList &);
+ CSVExport(KoFilter * parent, const char * name, const TQStringList &);
virtual ~CSVExport() {}
virtual KoFilter::ConversiontqStatus convert( const TQCString & from, const TQCString & to );
diff --git a/filters/kspread/csv/csvexportdialog.h b/filters/kspread/csv/csvexportdialog.h
index aa350f01..4683c040 100644
--- a/filters/kspread/csv/csvexportdialog.h
+++ b/filters/kspread/csv/csvexportdialog.h
@@ -36,7 +36,7 @@ class CSVExportDialog : public KDialogBase
Q_OBJECT
TQ_OBJECT
public:
- CSVExportDialog(TQWidget * tqparent);
+ CSVExportDialog(TQWidget * parent);
~CSVExportDialog();
TQChar getDelimiter() const;
diff --git a/filters/kspread/csv/csvimport.h b/filters/kspread/csv/csvimport.h
index 6f01a734..df14a756 100644
--- a/filters/kspread/csv/csvimport.h
+++ b/filters/kspread/csv/csvimport.h
@@ -28,7 +28,7 @@ class CSVFilter : public KoFilter {
TQ_OBJECT
public:
- CSVFilter(KoFilter *tqparent, const char *name, const TQStringList&);
+ CSVFilter(KoFilter *parent, const char *name, const TQStringList&);
virtual ~CSVFilter() {}
virtual KoFilter::ConversiontqStatus convert( const TQCString& from, const TQCString& to );
diff --git a/filters/kspread/dbase/dbaseimport.h b/filters/kspread/dbase/dbaseimport.h
index 8d074f1e..39a0ac0e 100644
--- a/filters/kspread/dbase/dbaseimport.h
+++ b/filters/kspread/dbase/dbaseimport.h
@@ -30,7 +30,7 @@ class DBaseImport : public KoFilter {
public:
- DBaseImport ( TQObject *tqparent, const char* name, const TQStringList& );
+ DBaseImport ( TQObject *parent, const char* name, const TQStringList& );
virtual ~DBaseImport() {}
virtual KoFilter::ConversiontqStatus convert( const TQCString& from, const TQCString& to );
diff --git a/filters/kspread/excel/excelexport.h b/filters/kspread/excel/excelexport.h
index 946a1b09..029cdac1 100644
--- a/filters/kspread/excel/excelexport.h
+++ b/filters/kspread/excel/excelexport.h
@@ -13,7 +13,7 @@ class ExcelExport : public KoFilter {
TQ_OBJECT
public:
- ExcelExport(KoFilter *tqparent, const char*name, const TQStringList&);
+ ExcelExport(KoFilter *parent, const char*name, const TQStringList&);
virtual ~ExcelExport() {}
virtual KoFilter::ConversiontqStatus convert(const TQCString& from, const TQCString& to);
diff --git a/filters/kspread/excel/import/excelimport.h b/filters/kspread/excel/import/excelimport.h
index 77e7b747..5b733733 100644
--- a/filters/kspread/excel/import/excelimport.h
+++ b/filters/kspread/excel/import/excelimport.h
@@ -32,7 +32,7 @@ class ExcelImport : public KoFilter {
public:
- ExcelImport ( TQObject *tqparent, const char* name, const TQStringList& );
+ ExcelImport ( TQObject *parent, const char* name, const TQStringList& );
virtual ~ExcelImport();
virtual KoFilter::ConversiontqStatus convert( const TQCString& from, const TQCString& to );
diff --git a/filters/kspread/excel/sidewinder/excel.h b/filters/kspread/excel/sidewinder/excel.h
index c114aa80..8cbdfd53 100644
--- a/filters/kspread/excel/sidewinder/excel.h
+++ b/filters/kspread/excel/sidewinder/excel.h
@@ -2777,7 +2777,7 @@ public:
void setFormulaHidden( bool f );
/**
- * Returns the index of the tqparent stlye of this format.
+ * Returns the index of the parent stlye of this format.
* This refers to the index of the XFormat table which is constructed
* from a series of XFormat records.
*
@@ -2786,7 +2786,7 @@ public:
unsigned parentStyle() const;
/**
- * Sets the index of the tqparent stlye of this format.
+ * Sets the index of the parent stlye of this format.
* This refers to the index of the XFormat table which is constructed
* from a series of XFormat records.
*
diff --git a/filters/kspread/gnumeric/gnumericexport.h b/filters/kspread/gnumeric/gnumericexport.h
index 8cd89e38..392f0f72 100644
--- a/filters/kspread/gnumeric/gnumericexport.h
+++ b/filters/kspread/gnumeric/gnumericexport.h
@@ -34,7 +34,7 @@ class GNUMERICExport : public KoFilter {
TQ_OBJECT
public:
- GNUMERICExport(KoFilter *tqparent, const char*name, const TQStringList&);
+ GNUMERICExport(KoFilter *parent, const char*name, const TQStringList&);
virtual ~GNUMERICExport() {}
virtual KoFilter::ConversiontqStatus convert( const TQCString& from, const TQCString& to );
diff --git a/filters/kspread/gnumeric/gnumericimport.h b/filters/kspread/gnumeric/gnumericimport.h
index f5a46d10..b7fbd4bd 100644
--- a/filters/kspread/gnumeric/gnumericimport.h
+++ b/filters/kspread/gnumeric/gnumericimport.h
@@ -36,7 +36,7 @@ class GNUMERICFilter : public KoFilter
Q_OBJECT
TQ_OBJECT
public:
- GNUMERICFilter(KoFilter *tqparent, const char *name, const TQStringList&);
+ GNUMERICFilter(KoFilter *parent, const char *name, const TQStringList&);
virtual ~GNUMERICFilter() {}
virtual KoFilter::ConversiontqStatus convert( const TQCString& from, const TQCString& to );
diff --git a/filters/kspread/html/exportdialog.cc b/filters/kspread/html/exportdialog.cc
index 37720d6e..72dd6875 100644
--- a/filters/kspread/html/exportdialog.cc
+++ b/filters/kspread/html/exportdialog.cc
@@ -32,8 +32,8 @@
#include <exportdialog.h>
#include <exportwidget.h>
-ExportDialog::ExportDialog( TQWidget *tqparent, const char *name )
- : KDialogBase( tqparent, name, true, i18n("Export Sheet to HTML"), Ok|Cancel, No, true ), m_mainwidget( new ExportWidget( this ) )
+ExportDialog::ExportDialog( TQWidget *parent, const char *name )
+ : KDialogBase( parent, name, true, i18n("Export Sheet to HTML"), Ok|Cancel, No, true ), m_mainwidget( new ExportWidget( this ) )
{
kapp->restoreOverrideCursor();
diff --git a/filters/kspread/html/exportdialog.h b/filters/kspread/html/exportdialog.h
index 38cac112..29645540 100644
--- a/filters/kspread/html/exportdialog.h
+++ b/filters/kspread/html/exportdialog.h
@@ -29,7 +29,7 @@ class ExportDialog : public KDialogBase
Q_OBJECT
TQ_OBJECT
public:
- ExportDialog( TQWidget *tqparent = 0, const char *name = 0 );
+ ExportDialog( TQWidget *parent = 0, const char *name = 0 );
~ExportDialog();
void setSheets( const TQStringList & );
diff --git a/filters/kspread/html/htmlexport.h b/filters/kspread/html/htmlexport.h
index afb20883..09f904d3 100644
--- a/filters/kspread/html/htmlexport.h
+++ b/filters/kspread/html/htmlexport.h
@@ -36,7 +36,7 @@ class HTMLExport : public KoFilter {
Q_OBJECT
TQ_OBJECT
public:
- HTMLExport(KoFilter *tqparent, const char*name, const TQStringList&);
+ HTMLExport(KoFilter *parent, const char*name, const TQStringList&);
virtual ~HTMLExport();
virtual KoFilter::ConversiontqStatus convert( const TQCString& from, const TQCString& to );
diff --git a/filters/kspread/kexi/kspread_kexiimport.cc b/filters/kspread/kexi/kspread_kexiimport.cc
index 76a44e9a..15e8ee2a 100644
--- a/filters/kspread/kexi/kspread_kexiimport.cc
+++ b/filters/kspread/kexi/kspread_kexiimport.cc
@@ -61,7 +61,7 @@ K_EXPORT_COMPONENT_FACTORY( libkspreadkexiimport, KSpreadKexiImportFactory( "kof
//=============================================================================
-KSpreadKexiImport::KSpreadKexiImport(KoFilter *tqparent, const char *name, const TQStringList&)
+KSpreadKexiImport::KSpreadKexiImport(KoFilter *parent, const char *name, const TQStringList&)
{
}
diff --git a/filters/kspread/kexi/kspread_kexiimport.h b/filters/kspread/kexi/kspread_kexiimport.h
index 7da8d20f..aec65889 100644
--- a/filters/kspread/kexi/kspread_kexiimport.h
+++ b/filters/kspread/kexi/kspread_kexiimport.h
@@ -69,7 +69,7 @@ class KSpreadKexiImport : public KoFilter
/**
* Constructor. This constructor is usable with KGenericFactory.
*/
- KSpreadKexiImport(KoFilter *tqparent, const char *name, const TQStringList&);
+ KSpreadKexiImport(KoFilter *parent, const char *name, const TQStringList&);
/**
* Virtual destructor.
diff --git a/filters/kspread/kexi/kspread_kexiimportdialog.h b/filters/kspread/kexi/kspread_kexiimportdialog.h
index 81948f34..1476a25e 100644
--- a/filters/kspread/kexi/kspread_kexiimportdialog.h
+++ b/filters/kspread/kexi/kspread_kexiimportdialog.h
@@ -68,7 +68,7 @@ public:
* The dates in the dialog initialize to a complete calendar for the
* current month.
*/
- KSpreadKexiImportDialog(TQWidget* tqparent = 0, const char* name = 0);
+ KSpreadKexiImportDialog(TQWidget* parent = 0, const char* name = 0);
/**
* Virtual destructor.
diff --git a/filters/kspread/latex/export/format.h b/filters/kspread/latex/export/format.h
index c0ab61aa..7025c371 100644
--- a/filters/kspread/latex/export/format.h
+++ b/filters/kspread/latex/export/format.h
@@ -77,7 +77,7 @@ class Format: public XmlParser
*
* Creates a new instance of Format.
*
- * @param Para the tqparent class of the format.
+ * @param Para the parent class of the format.
*/
Format();
diff --git a/filters/kspread/latex/export/kspreadlatexexportdiaImpl.h b/filters/kspread/latex/export/kspreadlatexexportdiaImpl.h
index 33bb6222..9e3e02d2 100644
--- a/filters/kspread/latex/export/kspreadlatexexportdiaImpl.h
+++ b/filters/kspread/latex/export/kspreadlatexexportdiaImpl.h
@@ -41,7 +41,7 @@ class KSpreadLatexExportDiaImpl : public LatexExportDia
LatexExportIface* _iface;
public:
- KSpreadLatexExportDiaImpl( KoStore*, TQWidget* tqparent = 0,
+ KSpreadLatexExportDiaImpl( KoStore*, TQWidget* parent = 0,
const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
virtual ~KSpreadLatexExportDiaImpl();
diff --git a/filters/kspread/latex/export/latexexport.h b/filters/kspread/latex/export/latexexport.h
index 5812d316..e7c0312b 100644
--- a/filters/kspread/latex/export/latexexport.h
+++ b/filters/kspread/latex/export/latexexport.h
@@ -35,7 +35,7 @@ class LATEXExport : public KoFilter
TQ_OBJECT
public:
- LATEXExport(KoFilter *tqparent, const char *name, const TQStringList&);
+ LATEXExport(KoFilter *parent, const char *name, const TQStringList&);
virtual ~LATEXExport() {}
virtual KoFilter::ConversiontqStatus convert( const TQCString& from, const TQCString& to );
diff --git a/filters/kspread/latex/export/latexexportIface.cc b/filters/kspread/latex/export/latexexportIface.cc
index 80ca013d..f99e6745 100644
--- a/filters/kspread/latex/export/latexexportIface.cc
+++ b/filters/kspread/latex/export/latexexportIface.cc
@@ -22,7 +22,7 @@
#include "kspreadlatexexportdiaImpl.h"
/*
- * Constructs a KWordLatexExportDia which is a child of 'tqparent', with the
+ * Constructs a KWordLatexExportDia which is a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*
* The dialog will by default be modeless, unless you set 'modal' to
diff --git a/filters/kspread/opencalc/opencalcexport.cc b/filters/kspread/opencalc/opencalcexport.cc
index 6a0376f4..9e37597c 100644
--- a/filters/kspread/opencalc/opencalcexport.cc
+++ b/filters/kspread/opencalc/opencalcexport.cc
@@ -402,7 +402,7 @@ bool OpenCalcExport::exportContent( KoStore * store, const Doc * ksdoc )
return true;
}
-void exportNamedExpr( TQDomDocument & doc, TQDomElement & tqparent,
+void exportNamedExpr( TQDomDocument & doc, TQDomElement & parent,
AreaList const & namedAreas )
{
AreaList::const_iterator it = namedAreas.begin();
@@ -418,7 +418,7 @@ void exportNamedExpr( TQDomDocument & doc, TQDomElement & tqparent,
namedRange.setAttribute( "table:base-cell-address", convertRefToBase( ref.sheet_name, ref.rect ) );
namedRange.setAttribute( "table:cell-range-address", convertRefToRange( ref.sheet_name, ref.rect ) );
- tqparent.appendChild( namedRange );
+ parent.appendChild( namedRange );
++it;
}
@@ -1026,14 +1026,14 @@ void OpenCalcExport::exportMasterStyles( TQDomDocument & doc, TQDomElement & mas
}
void OpenCalcExport::addText( TQString const & text, TQDomDocument & doc,
- TQDomElement & tqparent )
+ TQDomElement & parent )
{
if (text.length() > 0 )
- tqparent.appendChild( doc.createTextNode( text ) );
+ parent.appendChild( doc.createTextNode( text ) );
}
void OpenCalcExport::convertPart( TQString const & part, TQDomDocument & doc,
- TQDomElement & tqparent, const Doc * ksdoc )
+ TQDomElement & parent, const Doc * ksdoc )
{
TQString text;
TQString var;
@@ -1052,54 +1052,54 @@ void OpenCalcExport::convertPart( TQString const & part, TQDomDocument & doc,
inVar = false;
if ( var == "<page>" )
{
- addText( text, doc, tqparent );
+ addText( text, doc, parent );
TQDomElement page = doc.createElement( "text:page-number" );
page.appendChild( doc.createTextNode( "1" ) );
- tqparent.appendChild( page );
+ parent.appendChild( page );
}
else if ( var == "<pages>" )
{
- addText( text, doc, tqparent );
+ addText( text, doc, parent );
TQDomElement page = doc.createElement( "text:page-count" );
page.appendChild( doc.createTextNode( "99" ) );
- tqparent.appendChild( page );
+ parent.appendChild( page );
}
else if ( var == "<date>" )
{
- addText( text, doc, tqparent );
+ addText( text, doc, parent );
TQDomElement t = doc.createElement( "text:date" );
t.setAttribute( "text:date-value", "0-00-00" );
// todo: "style:data-style-name", "N2"
t.appendChild( doc.createTextNode( TQDate::tqcurrentDate().toString() ) );
- tqparent.appendChild( t );
+ parent.appendChild( t );
}
else if ( var == "<time>" )
{
- addText( text, doc, tqparent );
+ addText( text, doc, parent );
TQDomElement t = doc.createElement( "text:time" );
t.appendChild( doc.createTextNode( TQTime::currentTime().toString() ) );
- tqparent.appendChild( t );
+ parent.appendChild( t );
}
else if ( var == "<file>" ) // filepath + name
{
- addText( text, doc, tqparent );
+ addText( text, doc, parent );
TQDomElement t = doc.createElement( "text:file-name" );
t.setAttribute( "text:display", "full" );
t.appendChild( doc.createTextNode( "???" ) );
- tqparent.appendChild( t );
+ parent.appendChild( t );
}
else if ( var == "<name>" ) // filename
{
- addText( text, doc, tqparent );
+ addText( text, doc, parent );
TQDomElement t = doc.createElement( "text:title" );
t.appendChild( doc.createTextNode( "???" ) );
- tqparent.appendChild( t );
+ parent.appendChild( t );
}
else if ( var == "<author>" )
{
@@ -1108,7 +1108,7 @@ void OpenCalcExport::convertPart( TQString const & part, TQDomDocument & doc,
text += authorPage->fullName();
- addText( text, doc, tqparent );
+ addText( text, doc, parent );
}
else if ( var == "<email>" )
{
@@ -1117,7 +1117,7 @@ void OpenCalcExport::convertPart( TQString const & part, TQDomDocument & doc,
text += authorPage->email();
- addText( text, doc, tqparent );
+ addText( text, doc, parent );
}
else if ( var == "<org>" )
{
@@ -1126,21 +1126,21 @@ void OpenCalcExport::convertPart( TQString const & part, TQDomDocument & doc,
text += authorPage->company();
- addText( text, doc, tqparent );
+ addText( text, doc, parent );
}
else if ( var == "<sheet>" )
{
- addText( text, doc, tqparent );
+ addText( text, doc, parent );
TQDomElement s = doc.createElement( "text:sheet-name" );
s.appendChild( doc.createTextNode( "???" ) );
- tqparent.appendChild( s );
+ parent.appendChild( s );
}
else
{
// no known variable:
text += var;
- addText( text, doc, tqparent );
+ addText( text, doc, parent );
}
text = "";
@@ -1156,7 +1156,7 @@ void OpenCalcExport::convertPart( TQString const & part, TQDomDocument & doc,
if ( !text.isEmpty() || !var.isEmpty() )
{
//we don't have var at the end =>store it
- addText( text+var, doc, tqparent );
+ addText( text+var, doc, parent );
}
}
diff --git a/filters/kspread/opencalc/opencalcexport.h b/filters/kspread/opencalc/opencalcexport.h
index 54748144..97832a9a 100644
--- a/filters/kspread/opencalc/opencalcexport.h
+++ b/filters/kspread/opencalc/opencalcexport.h
@@ -43,7 +43,7 @@ class OpenCalcExport : public KoFilter
TQ_OBJECT
public:
- OpenCalcExport( KoFilter * tqparent, const char * name, const TQStringList & );
+ OpenCalcExport( KoFilter * parent, const char * name, const TQStringList & );
virtual ~OpenCalcExport() {}
virtual KoFilter::ConversiontqStatus convert( const TQCString & from,
@@ -76,9 +76,9 @@ class OpenCalcExport : public KoFilter
void maxRowCols( const KSpread::Sheet * sheet,
int & maxCols, int & maxRows );
void convertPart( TQString const & part, TQDomDocument & doc,
- TQDomElement & tqparent, const KSpread::Doc * ksdoc );
+ TQDomElement & parent, const KSpread::Doc * ksdoc );
void addText( TQString const & text, TQDomDocument & doc,
- TQDomElement & tqparent );
+ TQDomElement & parent );
void createDefaultStyles();
TQString convertFormula( TQString const & formula ) const;
diff --git a/filters/kspread/opencalc/opencalcimport.cc b/filters/kspread/opencalc/opencalcimport.cc
index f52ffd0f..376a8f77 100644
--- a/filters/kspread/opencalc/opencalcimport.cc
+++ b/filters/kspread/opencalc/opencalcimport.cc
@@ -476,8 +476,8 @@ bool OpenCalcImport::readCells( TQDomElement & rowNode, Sheet * table, int row,
cell = table->nonDefaultCell( columns, row );
TQString psName( "Default" );
- if ( e.hasAttributeNS( ooNS::style, "tqparent-style-name" ) )
- psName = e.attributeNS( ooNS::style, "tqparent-style-name", TQString() );
+ if ( e.hasAttributeNS( ooNS::style, "parent-style-name" ) )
+ psName = e.attributeNS( ooNS::style, "parent-style-name", TQString() );
kdDebug(30518) << "Default style: " << psName << endl;
Format * tqlayout = m_defaultStyles[psName];
@@ -2221,11 +2221,11 @@ void OpenCalcImport::readInStyle( Format * tqlayout, TQDomElement const & style
kdDebug(30518) << "** Reading Style: " << style.tagName() << "; " << style.attributeNS( ooNS::style, "name", TQString()) << endl;
if ( style.localName() == "style" && style.namespaceURI()==ooNS::style)
{
- if ( style.hasAttributeNS( ooNS::style, "tqparent-style-name" ) )
+ if ( style.hasAttributeNS( ooNS::style, "parent-style-name" ) )
{
Format * cp
- = m_defaultStyles.find( style.attributeNS( ooNS::style, "tqparent-style-name", TQString() ) );
- kdDebug(30518) << "Copying tqlayout from " << style.attributeNS( ooNS::style, "tqparent-style-name", TQString() ) << endl;
+ = m_defaultStyles.find( style.attributeNS( ooNS::style, "parent-style-name", TQString() ) );
+ kdDebug(30518) << "Copying tqlayout from " << style.attributeNS( ooNS::style, "parent-style-name", TQString() ) << endl;
if ( cp != 0 )
tqlayout->copy( *cp );
diff --git a/filters/kspread/opencalc/opencalcimport.h b/filters/kspread/opencalc/opencalcimport.h
index b7dca822..cd1f23b6 100644
--- a/filters/kspread/opencalc/opencalcimport.h
+++ b/filters/kspread/opencalc/opencalcimport.h
@@ -44,7 +44,7 @@ class OpenCalcImport : public KoFilter
Q_OBJECT
TQ_OBJECT
public:
- OpenCalcImport( KoFilter * tqparent, const char * name, const TQStringList & );
+ OpenCalcImport( KoFilter * parent, const char * name, const TQStringList & );
virtual ~OpenCalcImport();
virtual KoFilter::ConversiontqStatus convert( TQCString const & from, TQCString const & to );
diff --git a/filters/kspread/opencalc/opencalcstyleexport.cc b/filters/kspread/opencalc/opencalcstyleexport.cc
index 2c81a2cc..f075713a 100644
--- a/filters/kspread/opencalc/opencalcstyleexport.cc
+++ b/filters/kspread/opencalc/opencalcstyleexport.cc
@@ -200,7 +200,7 @@ void OpenCalcStyles::addCellStyles( TQDomDocument & doc, TQDomElement & autoStyl
TQDomElement ts = doc.createElement( "style:style" );
ts.setAttribute( "style:name", t->name );
ts.setAttribute( "style:family", "table-cell" );
- ts.setAttribute( "style:tqparent-style-name", "Default" );
+ ts.setAttribute( "style:parent-style-name", "Default" );
if ( t->numberStyle.length() > 0 )
ts.setAttribute( "style:data-style-name", t->numberStyle );
diff --git a/filters/kspread/qpro/qproimport.h b/filters/kspread/qpro/qproimport.h
index 031f5cdf..1c3c7d85 100644
--- a/filters/kspread/qpro/qproimport.h
+++ b/filters/kspread/qpro/qproimport.h
@@ -34,7 +34,7 @@ class QpImport : public KoFilter {
TQ_OBJECT
public:
- QpImport(KoFilter* tqparent, const char* name, const TQStringList&);
+ QpImport(KoFilter* parent, const char* name, const TQStringList&);
virtual ~QpImport() {}
virtual KoFilter::ConversiontqStatus convert( const TQCString& from, const TQCString& to );
diff --git a/filters/kspread/csv/csvdialog.cpp b/filters/kspread/csv/csvdialog.cpp
index 47cb19fe..17e9cc65 100644
--- a/filters/kspread/csv/csvdialog.cpp
+++ b/filters/kspread/csv/csvdialog.cpp
@@ -41,8 +41,8 @@
#include <kmessagebox.h>
#include <kcharsets.h>
-CSVDialog::CSVDialog(TQWidget* tqparent, TQByteArray& fileArray, const TQString /*seperator*/)
- : KDialogBase(tqparent, 0, true, TQString(), Ok|Cancel, No, true),
+CSVDialog::CSVDialog(TQWidget* parent, TQByteArray& fileArray, const TQString /*seperator*/)
+ : KDialogBase(parent, 0, true, TQString(), Ok|Cancel, No, true),
m_adjustRows(false),
m_adjustCols(false),
m_startRow(0),
@@ -612,7 +612,7 @@ TQTextCodec* CSVDialog::getCodec(void) const
{
// Default: UTF-8
kdWarning(30502) << "Cannot find encoding:" << strCodec << endl;
// ### TODO: what tqparent to use?
KMessageBox::error( 0, i18n("Cannot find encoding: %1").tqarg( strCodec ) );
return 0;
}
@@ -612,7 +612,7 @@ TQTextCodec* CSVDialog::getCodec(void) const
// Default: UTF-8
kdWarning(30502) << "Cannot find encoding:" << strCodec << endl;
- // ### TODO: what tqparent to use?
+ // ### TODO: what parent to use?
KMessageBox::error( 0, i18n("Cannot find encoding: %1").tqarg( strCodec ) );
return 0;
diff --git a/filters/kspread/csv/csvexportdialog.cpp b/filters/kspread/csv/csvexportdialog.cpp
index 268f322b..a4ef1347 100644
--- a/filters/kspread/csv/csvexportdialog.cpp
+++ b/filters/kspread/csv/csvexportdialog.cpp
@@ -48,8 +48,8 @@
using namespace KSpread;
-CSVExportDialog::CSVExportDialog( TQWidget * tqparent )
- : KDialogBase( tqparent, 0, true, TQString(), Ok | Cancel, No, true ),
+CSVExportDialog::CSVExportDialog( TQWidget * parent )
+ : KDialogBase( parent, 0, true, TQString(), Ok | Cancel, No, true ),
m_dialog( new ExportDialogUI( this ) ),
m_delimiter( "," ),
m_textquote('"')
@@ -305,7 +305,7 @@ TQTextCodec* CSVExportDialog::getCodec(void) const
{
// Default: UTF-8
kdWarning(30502) << "Cannot find encoding:" << strCodec << endl;
// ### TODO: what tqparent to use?
KMessageBox::error( 0, i18n("Cannot find encoding: %1").tqarg( strCodec ) );
return 0;
}
@@ -305,7 +305,7 @@ TQTextCodec* CSVExportDialog::getCodec(void) const
// Default: UTF-8
kdWarning(30502) << "Cannot find encoding:" << strCodec << endl;
- // ### TODO: what tqparent to use?
+ // ### TODO: what parent to use?
KMessageBox::error( 0, i18n("Cannot find encoding: %1").tqarg( strCodec ) );
return 0;
diff --git a/filters/kspread/excel/sidewinder/pole.cpp b/filters/kspread/excel/sidewinder/pole.cpp
index fac4aa62..38fe8cb5 100644
--- a/filters/kspread/excel/sidewinder/pole.cpp
+++ b/filters/kspread/excel/sidewinder/pole.cpp
@@ -114,7 +114,7 @@ class DirTree
DirEntry* entry( unsigned index );
DirEntry* entry( const std::string& name, bool create=false );
int indexOf( DirEntry* e );
- int tqparent( unsigned index );
+ int parent( unsigned index );
std::string fullName( unsigned index );
std::vector<unsigned> tqchildren( unsigned index );
void load( unsigned char* buffer, unsigned len );
@@ -507,7 +507,7 @@ int DirTree::indexOf( DirEntry* e )
return -1;
}
-int DirTree::tqparent( unsigned index )
+int DirTree::parent( unsigned index )
{
// brute-force, basically we iterate for each entries, find its tqchildren
// and check if one of the tqchildren is 'index'
@@ -529,7 +529,7 @@ std::string DirTree::fullName( unsigned index )
std::string result = entry( index )->name;
result.insert( 0, "/" );
- int p = tqparent( index );
+ int p = parent( index );
DirEntry * _entry = 0;
while( p > 0 )
{
@@ -597,7 +597,7 @@ DirEntry* DirTree::entry( const std::string& name, bool create )
if( !create ) return (DirEntry*)0;
// create a new entry
- unsigned tqparent = index;
+ unsigned parent = index;
entries.push_back( DirEntry() );
index = entryCount()-1;
DirEntry* e = entry( index );
@@ -608,8 +608,8 @@ DirEntry* DirTree::entry( const std::string& name, bool create )
e->start = 0;
e->child = End;
e->prev = End;
- e->next = entry(tqparent)->child;
- entry(tqparent)->child = index;
+ e->next = entry(parent)->child;
+ entry(parent)->child = index;
}
}
@@ -1138,7 +1138,7 @@ StreamIO::StreamIO( StorageIO* s, DirEntry* e)
updateCache();
}
// FIXME tell tqparent we're gone
StreamIO::~StreamIO()
{
delete[] cache_data;
@@ -1285,8 +1285,8 @@ std::list<std::string> Storage::entries( const std::string& path )
DirEntry* e = dt->entry( path, false );
if( e && e->dir )
{
- unsigned tqparent = dt->indexOf( e );
- std::vector<unsigned> tqchildren = dt->tqchildren( tqparent );
+ unsigned parent = dt->indexOf( e );
+ std::vector<unsigned> tqchildren = dt->tqchildren( parent );
for( unsigned i = 0; i < tqchildren.size(); i++ )
result.push_back( dt->entry( tqchildren[i] )->name );
}
@@ -1307,7 +1307,7 @@ Stream::Stream( Storage* storage, const std::string& name )
io = storage->io->streamIO( name );
}
// FIXME tell tqparent we're gone
Stream::~Stream()
{
delete io;
@@ -1138,7 +1138,7 @@ StreamIO::StreamIO( StorageIO* s, DirEntry* e)
updateCache();
}
-// FIXME tell tqparent we're gone
+// FIXME tell parent we're gone
StreamIO::~StreamIO()
{
@@ -1307,7 +1307,7 @@ Stream::Stream( Storage* storage, const std::string& name )
io = storage->io->streamIO( name );
}
-// FIXME tell tqparent we're gone
+// FIXME tell parent we're gone
Stream::~Stream()
{
diff --git a/filters/kspread/kexi/kspread_kexiimportdialog.cc b/filters/kspread/kexi/kspread_kexiimportdialog.cc
index 9d30ee38..9ddf240f 100644
--- a/filters/kspread/kexi/kspread_kexiimportdialog.cc
+++ b/filters/kspread/kexi/kspread_kexiimportdialog.cc
@@ -54,12 +54,12 @@
/**
* Constructor
* @param tqparent Pointer to kspread view
* @param name Name of the dialog
* @return None
*/
- KSpreadKexiImportDialog::KSpreadKexiImportDialog(TQWidget* tqparent, const char* name)
- : KSpreadKexiImportDialogBase(tqparent,name)
+ KSpreadKexiImportDialog::KSpreadKexiImportDialog(TQWidget* parent, const char* name)
+ : KSpreadKexiImportDialogBase(parent,name)
{
connect(this->m_insertButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(accept()));
connect(this->m_cancelButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(reject()));
@@ -54,12 +54,12 @@
/**
* Constructor
- * @param tqparent Pointer to kspread view
+ * @param parent Pointer to kspread view
* @param name Name of the dialog
* @return None
diff --git a/filters/kspread/latex/export/kspreadlatexexportdiaImpl.cc b/filters/kspread/latex/export/kspreadlatexexportdiaImpl.cc
index 479bb547..a7f03f60 100644
--- a/filters/kspread/latex/export/kspreadlatexexportdiaImpl.cc
+++ b/filters/kspread/latex/export/kspreadlatexexportdiaImpl.cc
@@ -49,15 +49,15 @@
#endif*/
/*
* Constructs a KSpreadLatexExportDiaImpl which is a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*
* The dialog will by default be modeless, unless you set 'modal' to
* TRUE to construct a modal dialog.
*/
-KSpreadLatexExportDiaImpl::KSpreadLatexExportDiaImpl(KoStore* in, TQWidget* tqparent,
+KSpreadLatexExportDiaImpl::KSpreadLatexExportDiaImpl(KoStore* in, TQWidget* parent,
const char* name_, bool modal, WFlags fl )
- : LatexExportDia( tqparent, name_, modal, fl ), _in( in )
+ : LatexExportDia( parent, name_, modal, fl ), _in( in )
{
int i = 0;
@@ -49,15 +49,15 @@
#endif*/
/*
- * Constructs a KSpreadLatexExportDiaImpl which is a child of 'tqparent', with the
+ * Constructs a KSpreadLatexExportDiaImpl which is a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*